================
 Citing HyperSpy
================

If HyperSpy has been significant to a project that leads to an academic publication,
please acknowledge that fact by citing the software. You can use the following bibtex
entry

.. code-block:: bibtex

    @misc{francisco_de_la_pena_2015_27735,
      author       = {Francisco de la Peña and
                      Vidar Tonaas Fauske and
                      Pierre Burdet and
                      Tomas Ostasevicius and
                      Mike Sarahan and
                      Magnus Nord and
                      Joshua A. Taillon and
                      Duncan Johnstone and
                      Katherine E. MacArthur and
                      Alberto Eljarrat and
                      Stefano Mazzucco and
                      Jan Caron and
                      Tom Furnival and
                      Michael Walls and
                      Eric Prestat and
                      Gaël Donval and
                      Ben Martineau and
                      Luiz Fernando Zagonel and
                      Petras Jokubauskas and
                      Thomas Aarholt and
                      and Andreas Garmannslund and
                      Ilya Iyengar and
                      },
      title        = {hyperspy: HyperSpy 0.8.5},
      month        = jun,
      year         = 2016,
      doi          = {10.5281/zenodo.54004},
      url          = {http://dx.doi.org/10.5281/zenodo.54004}
    }


or click on the DOI badge below for more citation formats.

.. image:: https://zenodo.org/badge/doi/10.5281/zenodo.54004.svg
   :target: http://dx.doi.org/10.5281/zenodo.54004
